magneticalc.OverridePadding_Dialog.OverridePadding_Dialog

# ``magneticalc`.`OverridePadding_Dialog`.`OverridePadding_Dialog``

class documentation

`class OverridePadding_Dialog(QDialog2):`

Constructor: `OverridePadding_Dialog(gui)`

View In Hierarchy

OverridePadding_Dialog class.

Method | `__init__` | Initializes the dialog.
Method | `validate` | Validates the bounding box values and enables/disables the "Apply" button accordingly.
Class Variable | `BoundsRange` | Undocumented
Instance Variable | `bounds_max_spinbox` | Undocumented
Instance Variable | `bounds_min_spinbox` | Undocumented
Instance Variable | `buttons` | Undocumented
Instance Variable | `gui` | Undocumented

Inherited from `QDialog2`:

Method | `show` | Shows this dialog.
Method | `showEvent` | Gets called when the dialog is opened.
Instance Variable | `user_accepted` | Undocumented

Inherited from `QLayouted` (via `QDialog2`):

Method | `addButtons` | Adds buttons.
Method | `addLayout` | Adds layout.
Method | `addSpacing` | Adds spacing.
Method | `addWidget` | Adds widget.
Method | `install_layout` | Installs this layout in the parent.
Instance Variable | `_layout` | Undocumented

def __init__(self, gui: `GUI`):
overrides `magneticalc.QtWidgets2.QDialog2.QDialog2.__init__`

Initializes the dialog.

Parameters
gui: `GUI` | GUI

def validate(self):

Validates the bounding box values and enables/disables the "Apply" button accordingly.

BoundsRange: `tuple[int, ...]` =

Undocumented

bounds_max_spinbox =

Undocumented

bounds_min_spinbox =

Undocumented

buttons =

Undocumented

gui =

Undocumented